Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2165)

Unified Diff: Source/web/WebNodeList.cpp

Issue 152243003: Rename WebNodeCollection to WebElementCollection for clarity (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/web/WebNodeCollection.cpp ('k') | Source/web/web.gypi » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/web/WebNodeList.cpp
diff --git a/Source/web/WebNodeList.cpp b/Source/web/WebNodeList.cpp
index eccaa9b33d5eed26bb8605d1b4bef4d276861cd7..19b6e9a0206ef160d0adcc7e509e523007effb26 100644
--- a/Source/web/WebNodeList.cpp
+++ b/Source/web/WebNodeList.cpp
@@ -53,8 +53,8 @@ public:
}
// We have null checks in the following methods because WebNodeList does not have a isNull() method
// and callers need to be moved to WebNodeCollection and need to handle null using
// WebNodeCollection::isNull().
virtual unsigned length() const OVERRIDE { return m_collection ? m_collection->length() : 0; }
virtual Node* item(unsigned index) const OVERRIDE { return m_collection ? m_collection->item(index) : 0; }
@@ -67,7 +67,7 @@ private:
RefPtr<HTMLCollection> m_collection;
};
-WebNodeList::WebNodeList(const WebNodeCollection& n)
+WebNodeList::WebNodeList(const WebElementCollection& n)
: m_private(0)
{
assign(NodeListWithInternalCollection::create(n.m_private).leakRef());
@@ -53,8 +53,8 @@ public:
}
// We have null checks in the following methods because WebNodeList does not have a isNull() method
- // and callers need to be moved to WebNodeCollection and need to handle null using
- // WebNodeCollection::isNull().
+ // and callers need to be moved to WebElementCollection and need to handle null using
+ // WebElementCollection::isNull().
virtual unsigned length() const OVERRIDE { return m_collection ? m_collection->length() : 0; }
virtual Node* item(unsigned index) const OVERRIDE { return m_collection ? m_collection->item(index) : 0; }
« no previous file with comments | « Source/web/WebNodeCollection.cpp ('k') | Source/web/web.gypi » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698